@@ -56,6 +56,7 @@ SUPPORTED_GROUPS = [
     "posterior_predictive",
     "predictions",
     "log_likelihood",
+    "log_prior",
     "sample_stats",
     "prior",
     "prior_predictive",
@@ -63,6 +64,8 @@ SUPPORTED_GROUPS = [
     "observed_data",
     "constant_data",
     "predictions_constant_data",
+    "unconstrained_posterior",
+    "unconstrained_prior",
 ]
 
 WARMUP_TAG = "warmup_"
@@ -73,6 +76,7 @@ SUPPORTED_GROUPS_WARMUP = [
     f"{WARMUP_TAG}predictions",
     f"{WARMUP_TAG}sample_stats",
     f"{WARMUP_TAG}log_likelihood",
+    f"{WARMUP_TAG}log_prior",
 ]
 
 SUPPORTED_GROUPS_ALL = SUPPORTED_GROUPS + SUPPORTED_GROUPS_WARMUP
@@ -250,8 +254,7 @@ class InferenceData(Mapping[str, xr.Dataset]):
 
     def __iter__(self) -> Iterator[str]:
         """Iterate over groups in InferenceData object."""
-        for group in self._groups_all:
-            yield group
+        yield from self._groups_all
 
     def __contains__(self, key: object) -> bool:
         """Return True if the named item is present, and False otherwise."""
@@ -1490,7 +1493,7 @@ class InferenceData(Mapping[str, xr.Dataset]):
 
             import numpy as np
             rng = np.random.default_rng(73)
-            ary = rng.normal(size=(post.dims["chain"], post.dims["draw"], obs.dims["match"]))
+            ary = rng.normal(size=(post.sizes["chain"], post.sizes["draw"], obs.sizes["match"]))
             idata.add_groups(
                 log_likelihood={"home_points": ary},
                 dims={"home_points": ["match"]},
