@@ -15,6 +15,7 @@ def plot_violin(
     transform=None,
     quartiles=True,
     rug=False,
+    side="both",
     hdi_prob=None,
     shade=0.35,
     bw="default",
@@ -61,6 +62,10 @@ def plot_violin(
         intervals. Defaults to ``True``.
     rug: bool
         If ``True`` adds a jittered rugplot. Defaults to ``False``.
+    side : {"both", "left", "right"}, default "both"
+        If ``both``, both sides of the violin plot are rendered. If ``left`` or ``right``, only
+        the respective side is rendered. By separately plotting left and right halfs with
+        different data, split violin plots can be achieved.
     hdi_prob: float, optional
         Plots highest posterior density interval for chosen percentage of density.
         Defaults to 0.94.
@@ -147,9 +152,8 @@ def plot_violin(
 
     if hdi_prob is None:
         hdi_prob = rcParams["stats.hdi_prob"]
-    else:
-        if not 1 >= hdi_prob > 0:
-            raise ValueError("The value of hdi_prob should be in the interval (0, 1]")
+    elif not 1 >= hdi_prob > 0:
+        raise ValueError("The value of hdi_prob should be in the interval (0, 1]")
 
     violinplot_kwargs = dict(
         ax=ax,
@@ -163,6 +167,7 @@ def plot_violin(
         shade=shade,
         rug=rug,
         rug_kwargs=rug_kwargs,
+        side=side,
         bw=bw,
         textsize=textsize,
         labeller=labeller,
@@ -177,6 +182,9 @@ def plot_violin(
         backend = rcParams["plot.backend"]
     backend = backend.lower()
 
+    if side not in ("both", "left", "right"):
+        raise ValueError(f"'side' can only be 'both', 'left', or 'right', got: '{side}'")
+
     # TODO: Add backend kwargs
     plot = get_plotting_function("plot_violin", "violinplot", backend)
     ax = plot(**violinplot_kwargs)
